@@ -29,7 +29,7 @@
 #ifndef __GLEWLWYD_H_
 #define __GLEWLWYD_H_
 
-#define _GLEWLWYD_VERSION_ "1.4.6"
+#define _GLEWLWYD_VERSION_ "1.4.9"
 
 #include <jansson.h>
 #include <jwt.h>
@@ -47,12 +47,9 @@
 #include <ldap.h>
 
 /** Angharad libraries **/
-#define U_DISABLE_WEBSOCKET
 #include <ulfius.h>
 #include <yder.h>
 
-#define _HOEL_MARIADB
-#define _HOEL_SQLITE
 #include <hoel.h>
 
 #if MHD_VERSION < 0x00093800
@@ -157,7 +154,7 @@ struct _auth_ldap {
   char *            bind_passwd;
   struct crypt_data cur_crypt_data;
   int               search_scope;
-	ber_int_t         page_size;
+  ber_int_t         page_size;
   
   char *  base_search_user;
   char *  filter_user_read;
