@@ -176,7 +176,7 @@ START_TEST(test_glwd_crud_client_connect_success)
   int res = run_simple_test(NULL, "POST", url, "new_client", "password", NULL, &body, 200, NULL, "access_token", NULL);
   free(url);
   u_map_clean(&body);
-	ck_assert_int_eq(res, 1);
+  ck_assert_int_eq(res, 1);
 }
 END_TEST
 
@@ -201,10 +201,11 @@ START_TEST(test_glwd_crud_client_connect_fail)
   int res = run_simple_test(NULL, "POST", url, "new_client", "password", NULL, &body, 403, NULL, NULL, NULL);
   free(url);
   u_map_clean(&body);
-	ck_assert_int_eq(res, 1);
+  ck_assert_int_eq(res, 1);
 }
 END_TEST
 
+#ifndef WITHOUT_LDAP
 START_TEST(test_glwd_crud_client_add_ok_ldap)
 {
   json_t * json_body;
@@ -312,6 +313,7 @@ START_TEST(test_glwd_crud_client_delete_new_ldap)
   ck_assert_int_eq(res, 1);
 }
 END_TEST
+#endif
 
 START_TEST(test_glwd_crud_client_add_ok_no_source)
 {
@@ -439,6 +441,7 @@ static Suite *glewlwyd_suite(void)
   tcase_add_test(tc_core, test_glwd_crud_client_connect_success);
   tcase_add_test(tc_core, test_glwd_crud_client_delete_new_database);
   tcase_add_test(tc_core, test_glwd_crud_client_connect_fail);
+#ifndef WITHOUT_LDAP
   tcase_add_test(tc_core, test_glwd_crud_client_add_ok_ldap);
   tcase_add_test(tc_core, test_glwd_crud_client_search_success);
   tcase_add_test(tc_core, test_glwd_crud_client_add_invalid_ldap);
@@ -447,6 +450,7 @@ static Suite *glewlwyd_suite(void)
   tcase_add_test(tc_core, test_glwd_crud_client_get_new_updated_ldap);
   tcase_add_test(tc_core, test_glwd_crud_client_connect_success);
   tcase_add_test(tc_core, test_glwd_crud_client_delete_new_ldap);
+#endif
   tcase_add_test(tc_core, test_glwd_crud_client_connect_fail);
   tcase_add_test(tc_core, test_glwd_crud_client_add_ok_no_source);
   tcase_add_test(tc_core, test_glwd_crud_client_search_success);
@@ -465,12 +469,12 @@ static Suite *glewlwyd_suite(void)
 
 int main(int argc, char *argv[])
 {
-  int number_failed;
+  int number_failed = 0;
   Suite *s;
   SRunner *sr;
   struct _u_request auth_req;
   struct _u_response auth_resp;
-  int res;
+  int res, do_test = 0;
   
   y_init_logs("Glewlwyd test", Y_LOG_MODE_CONSOLE, Y_LOG_LEVEL_DEBUG, NULL, "Starting Glewlwyd test");
   
@@ -492,18 +496,21 @@ int main(int argc, char *argv[])
     u_map_put(user_req.map_header, "Authorization", bearer_token);
     free(bearer_token);
     json_decref(json_body);
+    do_test = 1;
   }
   ulfius_clean_request(&auth_req);
   ulfius_clean_response(&auth_resp);
   
-  s = glewlwyd_suite();
-  sr = srunner_create(s);
+  if (do_test) {
+    s = glewlwyd_suite();
+    sr = srunner_create(s);
 
-  srunner_run_all(sr, CK_VERBOSE);
-  number_failed = srunner_ntests_failed(sr);
-  srunner_free(sr);
+    srunner_run_all(sr, CK_VERBOSE);
+    number_failed = srunner_ntests_failed(sr);
+    srunner_free(sr);
+  }
   
   ulfius_clean_request(&user_req);
   
-  return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+  return (do_test && number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
