@@ -251,12 +251,14 @@ END_TEST
 START_TEST(test_glwd_crud_user_get_new_database_empty_additional_property)
 {
   char * url = msprintf("%s/user/new_user?source=database", SERVER_URI);
-  json_t * j_new_user = json_pack("{sssssssssssos[ss]}",
+  json_t * j_new_user = json_pack("{sssssssssssssos[ss]}",
                         "login", "new_user",
                         "name", "New User",
                         "email", "test@glewlwyd.domain",
                         "additional_property_name", "new_property",
                         "additional_property_value", "",
+                        "source",
+                        "database",
                         "enabled", json_true(),
                         "scope", 
                           "scope1", "scope2");
@@ -314,6 +316,7 @@ START_TEST(test_glwd_crud_user_connect_fail_empty_password_new)
 }
 END_TEST
 
+#ifndef WITHOUT_LDAP
 START_TEST(test_glwd_crud_user_add_ok_ldap)
 {
   json_t * json_body;
@@ -417,6 +420,7 @@ START_TEST(test_glwd_crud_user_delete_new_ldap)
   ck_assert_int_eq(res, 1);
 }
 END_TEST
+#endif
 
 START_TEST(test_glwd_crud_user_add_ok_no_source)
 {
@@ -549,6 +553,7 @@ static Suite *glewlwyd_suite(void)
   tcase_add_test(tc_core, test_glwd_crud_user_get_new_database_empty_additional_property);
   tcase_add_test(tc_core, test_glwd_crud_user_delete_new_database_empty_additional_property);
   tcase_add_test(tc_core, test_glwd_crud_user_connect_fail_new);
+#ifndef WITHOUT_LDAP
   tcase_add_test(tc_core, test_glwd_crud_user_add_ok_ldap);
   tcase_add_test(tc_core, test_glwd_crud_user_search_success);
   tcase_add_test(tc_core, test_glwd_crud_user_connect_success_new);
@@ -563,6 +568,7 @@ static Suite *glewlwyd_suite(void)
   tcase_add_test(tc_core, test_glwd_crud_user_connect_fail_new);
   tcase_add_test(tc_core, test_glwd_crud_user_connect_fail_empty_password_new);
   tcase_add_test(tc_core, test_glwd_crud_user_delete_new_ldap);
+#endif
   tcase_add_test(tc_core, test_glwd_crud_user_connect_fail_new);
   tcase_add_test(tc_core, test_glwd_crud_user_add_ok_no_source);
   tcase_add_test(tc_core, test_glwd_crud_user_search_success);
@@ -587,12 +593,12 @@ static Suite *glewlwyd_suite(void)
 
 int main(int argc, char *argv[])
 {
-  int number_failed;
+  int number_failed = 0;
   Suite *s;
   SRunner *sr;
   struct _u_request auth_req;
   struct _u_response auth_resp;
-  int res;
+  int res, do_test = 0;
   
   y_init_logs("Glewlwyd test", Y_LOG_MODE_CONSOLE, Y_LOG_LEVEL_DEBUG, NULL, "Starting Glewlwyd test");
   
@@ -614,18 +620,21 @@ int main(int argc, char *argv[])
     u_map_put(user_req.map_header, "Authorization", bearer_token);
     free(bearer_token);
     json_decref(json_body);
+    do_test = 1;
   }
   ulfius_clean_request(&auth_req);
   ulfius_clean_response(&auth_resp);
   
-  s = glewlwyd_suite();
-  sr = srunner_create(s);
+  if (do_test) {
+    s = glewlwyd_suite();
+    sr = srunner_create(s);
 
-  srunner_run_all(sr, CK_VERBOSE);
-  number_failed = srunner_ntests_failed(sr);
-  srunner_free(sr);
+    srunner_run_all(sr, CK_VERBOSE);
+    number_failed = srunner_ntests_failed(sr);
+    srunner_free(sr);
+  }
   
   ulfius_clean_request(&user_req);
   
-  return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+  return (do_test && number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
